==> qtjambi-datavisualization-6.6.1-sources.jar: io/qt/datavis/QBarDataRow.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Template class that provides a dynamic array</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qlist.html">QBarDataRow</a></code></p>
 */
public class QBarDataRow extends io.qt.core.QList<io.qt.datavis.@NonNull QBarDataItem>
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QBarDataRow::<wbr/>QBarDataRow()</code></p>
     */
    public QBarDataRow(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QBarDataRow instance);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QBarDataRow(QPrivateConstructor p) { super(p); } 
    

    /**
     * Returns the objects's hash code computed by <code>qHash(QBarDataRow)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QBarDataRow clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QBarDataRow clone_native(long __this_nativeId);
}

==> qtjambi-datavisualization-6.6.3-sources.jar: io/qt/datavis/QBarDataRow.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Template class that provides a dynamic array</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qlist.html">QBarDataRow</a></code></p>
 */
public class QBarDataRow extends io.qt.core.QList<io.qt.datavis.@NonNull QBarDataItem>
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QBarDataRow::<wbr/>QBarDataRow()</code></p>
     */
    public QBarDataRow(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QBarDataRow instance);
    
    /**
     * <p>See <code>QBarDataRow::<wbr/>QBarDataRow(QBarDataRow)</code></p>
     */
    public QBarDataRow(io.qt.datavis.@StrictNonNull QBarDataRow other){
        super((QPrivateConstructor)null);
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QBarDataRow instance, io.qt.datavis.QBarDataRow other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QBarDataRow(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code>QBarDataRow::<wbr/>QBarDataRow(QBarDataRow)</code></p>
     */
    @QtUninvokable
    @Override
    public QBarDataRow clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QBarDataRow clone_native(long __this_nativeId);
}
